@@ -9,6 +9,8 @@ elif command -v python3.7; then
   PYTHON=python3.7
 elif command -v python3.6; then
   PYTHON=python3.6
+elif command -v python3.5; then
+  PYTHON=python3.5
 elif command -v python3; then
   PYTHON=python3
 else
@@ -18,7 +20,7 @@ fi
 
 if $PYTHON -m venv $TEMP; then
   source $TEMP/bin/activate
-  pip3 install requests jsonschema PyYaml alertlogic-sdk-python --no-cache-dir --ignore-requires-python
+  pip3 install alertlogic-sdk-definitions --no-cache-dir --ignore-requires-python
   curl https://raw.githubusercontent.com/alertlogic/alertlogic-sdk-definitions/master/scripts/validate_my_definition.py -o $TEMP/validate_my_definition.py
   if [ $# -eq 0 ]
   then
